import objectdraw.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JSlider;

/*
 * 
 * Example SwingFallingSnow: the main class that creates clouds, which in turn
 * create falling snowflakes.
 * 
 * This one uses Java Swing components to control cloud creation and
 * the wind speed and direction
 *
 * Jim Teresco, The College of Saint Rose, Fall 2014
 *
 * $Id: Snow.java 2452 2014-10-13 15:59:20Z terescoj $
 */

// Program which creates clouds which create snow when the user pressed the 
// button
public class Snow extends WindowController implements ActionListener {

    // constants for the moon size and location
    private static final double MOON_INSET = 50;
    private static final int MOON_SIZE = 70;

    // sizes and locations for the bricks
    private static final double BRICK_LINE = 40;  // from bottom
    private static final double BRICK_HEIGHT = 12;
    private static final double BRICK_WIDTH = 30;
    private static final double BRICK_SPACING = 3;

    // colors of the sky, mortar, and brick
    private final Color NIGHTSKY = new Color(50, 50, 100);
    private final Color MORTAR = new Color(200, 200, 200);
    private final Color BRICKRED = new Color(150, 40, 40);
    
    // allowed wind speeds
    private static final int MAX_WIND = 5;

    // image of the snow
    private Image snowPic;
    
    // our wind controller
    private JSlider windSlider;

    public void begin() {

        // we'll get the Swing components there first
        Container contentPane = getContentPane();
        
        // a panel to go on the bottom of the window
        JPanel southPanel = new JPanel();
        
        // a button to create a new cloud, add to panel, set up listener
        JButton cloudButton = new JButton("Create Cloud");
        southPanel.add(cloudButton);
        cloudButton.addActionListener(this);
        
        // a slider that will control the wind
        windSlider = new JSlider(JSlider.HORIZONTAL, -MAX_WIND, MAX_WIND, 0);
        southPanel.add(windSlider);
        
        // add the panel to the south
        contentPane.add(southPanel, BorderLayout.SOUTH);
        contentPane.validate();
        
        // now start drawing things on our canvas
        
        // where to draw next brick
        double brickPosition;

        // get leaf picture
        snowPic = getImage("snow.gif");

        // draw solid sky, mortar, and moon
        new FilledRect(0, 0, canvas.getWidth(), canvas.getHeight() - BRICK_LINE, canvas).setColor(NIGHTSKY);
        new FilledRect(0, canvas.getHeight() - BRICK_LINE, canvas.getWidth(), 
                       canvas.getHeight(),
                       canvas).setColor(MORTAR);
        new FilledOval(MOON_INSET,MOON_INSET,MOON_SIZE,MOON_SIZE,
                       canvas).setColor(Color.white);

        // add the bricks
        brickPosition = 0;
        while ( brickPosition < canvas.getWidth() ) {
            new FilledRect(brickPosition, canvas.getHeight() - BRICK_LINE,
                           BRICK_WIDTH, BRICK_HEIGHT,
                           canvas).setColor(BRICKRED);

            brickPosition = brickPosition + BRICK_WIDTH + BRICK_SPACING;
        }


    }

    public void actionPerformed(ActionEvent e) {
        // make a new snow-dropping cloud when the user presses
        // the (only) button
        new Cloud(snowPic, windSlider, canvas);
    }
}

